@@ -68,7 +68,7 @@ class AsyncOsuApi:
 
 
         response = await self.Client.get(url=self.BASE_URL+"/beatmaps/lookup", params=query_params, headers=kwargs["headers"])
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=Beatmap, obj=response.json())
     
@@ -100,7 +100,7 @@ class AsyncOsuApi:
             query_params["mods"] = mods
 
         response = await self.Client.get(url=self.BASE_URL+f"/beatmaps/{beatmap_id}/scores/users/{user_id}", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=BeatmapUserScore, obj=response.json())
     
@@ -126,7 +126,7 @@ class AsyncOsuApi:
             query_params["mode"] = mode
         
         response = await self.Client.get(url=self.BASE_URL+f"/beatmaps/{beatmap_id}/scores/users/{user_id}/all", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=Scores, obj=response.json())
     
@@ -160,7 +160,7 @@ class AsyncOsuApi:
                 raise c_TypeError(param_name="type",correct="str",wrong=type(type).__name__)
             
         response = await self.Client.get(url=self.BASE_URL+f"/beatmaps/{beatmap_id}/scores", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=BeatmapScores, obj=response.json())
     
@@ -178,7 +178,7 @@ class AsyncOsuApi:
         query_params["ids[]"] = beatmap_ids
 
         response = await self.Client.get(url=self.BASE_URL+"/beatmaps", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=Beatmaps, obj=response.json())
     
@@ -192,7 +192,7 @@ class AsyncOsuApi:
             raise c_TypeError(param_name="beatmap_id", correct="int", wrong=type(beatmap_id).__name__)
         
         response = await self.Client.get(url=self.BASE_URL+f"/beatmaps/{beatmap_id}", headers=kwargs["headers"])
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=Beatmap, obj=response.json())
     
@@ -229,7 +229,7 @@ class AsyncOsuApi:
             query_params["ruleset_id"] = ruleset_id
 
         response = await self.Client.post(url=self.BASE_URL+f"/beatmaps/{beatmap_id}/attributes", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=Attributes, obj=response.json())
     
@@ -256,7 +256,7 @@ class AsyncOsuApi:
             query_params["offset"] = offset
             
         response = await self.Client.get(url=self.BASE_URL+f"/users/{user_id}/kudosu", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=list[KudosuHistory], obj=response.json())
     
@@ -297,7 +297,7 @@ class AsyncOsuApi:
             query_params["offset"] = offset
 
         response = await self.Client.get(url=self.BASE_URL+f"/users/{user_id}/scores/{Type}", headers=self.base_headers, params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=list[Score], obj=response.json())
                 
@@ -329,7 +329,7 @@ class AsyncOsuApi:
             query_params["offset"] = offset
             
         response = await self.Client.get(url=self.BASE_URL+f"/users/{user_id}/beatmapsets/{Type}", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         if Type == BeatmapType.MOST_PLAYED.value:
             return parse_obj_as(type_=list[BeatmapPlaycount], obj=response.json())
@@ -358,7 +358,7 @@ class AsyncOsuApi:
             query_params["offset"] = offset
 
         response = await self.Client.get(url=self.BASE_URL+f"/users/{user_id}/recent_activity", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=list[Event], obj=response.json())
     
@@ -386,7 +386,7 @@ class AsyncOsuApi:
             query_params["key"] = key
 
         response = await self.Client.get(url=self.BASE_URL+f"/users/{username}/{mode}", headers=kwargs["headers"],params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=User, obj=response.json())
 
@@ -404,7 +404,7 @@ class AsyncOsuApi:
         query_params["ids[]"] = user_ids
 
         response = await self.Client.get(url=self.BASE_URL+"/users", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=Users, obj=response.json())
 
@@ -464,7 +464,7 @@ class AsyncOsuApi:
             query_params["variant"] = variant
 
         response = await self.Client.get(url=self.BASE_URL+f"/rankings/{mode}/{type}", headers=kwargs["headers"], params=query_params)
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=Rankings, obj=response.json())
     
@@ -473,6 +473,6 @@ class AsyncOsuApi:
     async def spotlights(self, **kwargs)->Spotlights:
 
         response = await self.Client.get(url=self.BASE_URL+"/spotlights", headers=kwargs["headers"])
-        if "error" in response.json():
+        if "error" in (res := response.json()) or "authentication" in res:
             return None
         return parse_obj_as(type_=Spotlights, obj=response.json())
\ No newline at end of file
