@@ -96,4 +96,8 @@ class Post(BaseModel):
     
 class Failtimes(BaseModel):
     exit: list[int] | None
-    fail: list[int] | None
\ No newline at end of file
+    fail: list[int] | None
+    
+class Achievement(BaseModel):
+	achieved_at: str
+	achievement_id: int
\ No newline at end of file
